/**
 * Copyright (c) 2007-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.bc.filetransfer;

import java.io.File;
import java.util.HashMap;
import java.util.Map;
import java.util.Map.Entry;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.Future;

import javax.jbi.JBIException;

import org.ow2.petals.component.framework.api.message.Exchange;
import org.ow2.petals.component.framework.bc.AbstractBindingComponent;

/**
 * @author Roland Naudin - EBM WebSourcing
 * @author Mathieu CARROLLE - EBM WebSourcing
 */
public class FileTransferComponent extends AbstractBindingComponent {

    /**
     * Store task for consume mode. Used to process file only once and by one
     * thread.<br/>
     * However the use of this map does not protect the processing of a file by
     * two components (HA feature). However, this map doesn't prevent the
     */
    private final Map<String, Future<?>> pendingProcessors = new ConcurrentHashMap<String, Future<?>>();

    private Map<String, File> transferedFileMap;

    public FileTransferComponent() {
        super();
        this.transferedFileMap = new HashMap<String, File>();
    }

    public void addTransferedFile(Exchange exchange, File file) {
        this.transferedFileMap.put(exchange.getExchangeId(), file);
    }

    /**
     * Remove from the map all done and cancelled task
     */
    public void cleanPendingProcessors() {
        for (Entry<String, Future<?>> entry : this.getPendingProcessors().entrySet()) {
            if (entry.getValue().isDone() || entry.getValue().isCancelled()) {
                this.getPendingProcessors().remove(entry.getKey());
            }
        }
    }

    public Map<String, Future<?>> getPendingProcessors() {
        return pendingProcessors;
    }

    public File getTransferedFile(Exchange exchange) {
        return this.transferedFileMap.remove(exchange.getExchangeId());
    }
    
    @Override
    protected void doStop() throws JBIException {
        // TODO Auto-generated method stub
        super.doStop();
    }
}
