/**
 * Copyright (c) 2007-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.bc.filetransfer.service.consume;

import java.io.File;

import org.ow2.petals.bc.filetransfer.util.LockFileFilter;

/**
 * Represents the SU parameter for consume mode.
 * @author Mathieu CARROLLE - EBM WebSourcing
 */
public class ConsumeConfiguration {

    /**
     * Backup directory (could be null)
     */
    private File backupDirectory;

    /**
     * The base-message defined in the SU
     */
    private String baseMsg;

    /**
     * Specified if base-message feature is activated
     */
    private boolean baseMsgOn;

    /**
     * Maximun number of ExternalEventProcessor thread
     */
    private int corePoolSize;

    /**
     * Timeout before idle ExternalEventProcessor thread will be removed
     */
    private long corePoolTimeout;

    /**
     * The first task execution delay
     */
    private long delay;

    /**
     * Regex for the file to process
     */
    private LockFileFilter filePattern;

    /**
     * The polling period
     */
    private long period;

    /**
     * Polled directory
     */
    private File polledDirectory;

    /**
     * Transfer mode (content or attachment)
     */
    private String transferMode;

    public ConsumeConfiguration(File backupDirectory, String baseMsg, boolean baseMsgOn,
            long delay, LockFileFilter filePattern, long period, File polledDirectory,
            String transferMode, int corePoolSize, long corePoolTimeout) {
        this.backupDirectory = backupDirectory;
        this.baseMsg = baseMsg;
        this.baseMsgOn = baseMsgOn;
        this.delay = delay;
        this.filePattern = filePattern;
        this.period = period;
        this.polledDirectory = polledDirectory;
        this.transferMode = transferMode;
        this.corePoolSize = corePoolSize;
        this.corePoolTimeout = corePoolTimeout;
    }

    /**
     * 
     * @return the backup directory or null if not specified
     */
    public File getBackupDirectory() {
        return backupDirectory;
    }

    /**
     * The base-message defined in the SU
     */
    public String getBaseMsg() {
        return baseMsg;
    }

    /**
     * The first task execution delay
     */
    public long getDelay() {
        return delay;
    }

    /**
     * Regex for the file to process
     */
    public LockFileFilter getFilePattern() {
        return filePattern;
    }

    /**
     * The polling period
     */
    public long getPeriod() {
        return period;
    }

    /**
     * Polled directory
     */
    public File getPolledDirectory() {
        return polledDirectory;
    }

    /**
     * Transfer mode (content or attachment)
     */
    public String getTransferMode() {
        return transferMode;
    }

    /**
     * Specified if base-message feature is activated
     */
    public boolean isBaseMsgOn() {
        return baseMsgOn;
    }

    /**
     * Backup directory (could be null)
     */
    public void setBackupDirectory(File backupDirectory) {
        this.backupDirectory = backupDirectory;
    }

    /**
     * The base-message defined in the SU
     */
    public void setBaseMsg(String baseMsg) {
        this.baseMsg = baseMsg;
    }

    /**
     * Specified if base-message feature is activated
     */
    public void setBaseMsgOn(boolean baseMsgOn) {
        this.baseMsgOn = baseMsgOn;
    }

    /**
     * The first task execution delay
     */
    public void setDelay(long delay) {
        this.delay = delay;
    }

    /**
     * Regex for the file to process
     */
    public void setFilePattern(LockFileFilter filePattern) {
        this.filePattern = filePattern;
    }

    /**
     * The polling period
     */
    public void setPeriod(long period) {
        this.period = period;
    }

    /**
     * Polled directory
     */
    public void setPolledDirectory(File polledDirectory) {
        this.polledDirectory = polledDirectory;
    }

    /**
     * Transfer mode (content or attachment)
     */
    public void setTransferMode(String transferMode) {
        this.transferMode = transferMode;
    }

    public int getCorePoolSize() {
        return corePoolSize;
    }

    public long getCorePoolTimeout() {
        return corePoolTimeout;
    }

    public void setCorePoolSize(int corePoolSize) {
        this.corePoolSize = corePoolSize;
    }

    public void setCorePoolTimeout(long corePoolTimeout) {
        this.corePoolTimeout = corePoolTimeout;
    }
}
