/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.bc.filetransfer.service.provide;

import static org.ow2.petals.bc.filetransfer.FileTransferConstants.DEFAULT_FILENAME;
import static org.ow2.petals.bc.filetransfer.FileTransferConstants.PARAM_FILENAME;

import java.util.logging.Logger;

import javax.jbi.messaging.MessagingException;

import org.ow2.petals.bc.filetransfer.FiletransferProvideExtFlowStepBeginLogData;
import org.ow2.petals.bc.filetransfer.util.FileTransferUtils;
import org.ow2.petals.commons.log.FlowAttributes;
import org.ow2.petals.commons.log.Level;
import org.ow2.petals.commons.log.PetalsExecutionContext;
import org.ow2.petals.component.framework.api.configuration.ConfigurationExtensions;
import org.ow2.petals.component.framework.api.message.Exchange;
import org.ow2.petals.component.framework.logger.ProvideExtFlowStepEndLogData;
import org.w3c.dom.Document;

import com.ebmwebsourcing.easycommons.lang.StringHelper;

/**
 * @author Mathieu CARROLLE - EBM WebSourcing
 */
public abstract class AbstractFileService {
	protected Logger logger;

	protected ConfigurationExtensions extensions;

	public AbstractFileService(ConfigurationExtensions extensions, Logger logger) {
		super();
		this.extensions = extensions;
		this.logger = logger;
	}

	public abstract void process(Exchange exchange, Document inMessageDoc)
			throws MessagingException;

	/**
	 * Get the target file name for a unique transfer.
	 * 
	 * @return
	 * @throws MessagingException
	 */
	public String getTargetFileName(final Exchange exchange) {
		String fileName = extensions.get(PARAM_FILENAME);
		if (StringHelper.isNullOrEmpty(fileName)) {
			if (exchange.getOperation() != null) {
				fileName = exchange.getOperationName() + ".xml";
			} else {
				fileName = DEFAULT_FILENAME;
			}
		}
		fileName = FileTransferUtils.addDateToFileName(fileName);
		return fileName;
	}
	
    protected void addMonitEndStepExtTrace() {
            FlowAttributes flowAttributes = PetalsExecutionContext.getFlowAttributes();
            String flowInstanceId = "";
            String flowStepId = "";
            if (flowAttributes != null) {
                flowInstanceId = flowAttributes.getFlowInstanceId();
                flowStepId = flowAttributes.getFlowStepId();
            }
            logger.log(Level.MONIT, "",
                    new ProvideExtFlowStepEndLogData(flowInstanceId, flowStepId));
    }
    
    protected void addMonitBeginStepExtTrace(String filePattern, String destDirName) {
        FlowAttributes flowAttributes = PetalsExecutionContext.getFlowAttributes();
        String flowInstanceId = "";
        String flowStepId = "";
        if (flowAttributes != null) {
            flowInstanceId = flowAttributes.getFlowInstanceId();
            flowStepId = flowAttributes.getFlowStepId();
        }
        
		FiletransferProvideExtFlowStepBeginLogData flowLogData = new FiletransferProvideExtFlowStepBeginLogData(
				flowInstanceId, flowStepId, filePattern,
				destDirName);
		this.logger.log(
Level.MONIT, "",
				flowLogData);
    }
}
