/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.bc.filetransfer.service.provide;

import java.io.File;
import java.io.IOException;
import java.util.logging.Logger;

import javax.jbi.messaging.MessagingException;

import org.ow2.petals.bc.filetransfer.FileTransferConstants;
import org.ow2.petals.bc.filetransfer.util.FileTransferUtils;
import org.ow2.petals.component.framework.api.Message.MEPConstants;
import org.ow2.petals.component.framework.api.configuration.ConfigurationExtensions;
import org.ow2.petals.component.framework.api.message.Exchange;
import org.w3c.dom.Document;
import org.w3c.dom.Node;

import com.ebmwebsourcing.easycommons.xml.XMLHelper;

/**
 * Delete a specified file. 
 * <p>
 * If a file pattern is specified like *.xml, we delete
 * the first matched file for this pattern.
 * </p>
 * 
 * @author Mathieu CARROLLE - EBM WebSourcing
 */
public class DelFileService extends AbstractFileService {

	public DelFileService(ConfigurationExtensions extensions, Logger logger) {
		super(extensions, logger);
	}

	@Override
	public void process(Exchange exchange, Document inMessageDoc)
			throws MessagingException {
		if (!exchange.isInOnlyPattern())
			throw new MessagingException(
					FileTransferUtils.getValidMepMessageForOperation("del",
							MEPConstants.IN_ONLY_PATTERN));

		final Node filePatternNode = XMLHelper.findChild(
				inMessageDoc.getDocumentElement(), null,
				FileTransferConstants.PARAM_FILENAME, true);
		if (filePatternNode == null) {
			throw new MessagingException("Missing element : "
					+ FileTransferConstants.PARAM_FILENAME);
		}
		final String filePattern = filePatternNode.getTextContent();
		if (filePattern == null) {
			throw new MessagingException("null value for parameter "
					+ FileTransferConstants.PARAM_FILENAME);
		}
		try {
			final File readDirectory = FileTransferUtils
					.getFolderPath(extensions);

			this.addMonitBeginStepExtTrace(filePattern, readDirectory.getName());

			final boolean isDeleted = this.del(readDirectory, filePattern);
			if (!isDeleted) {
				throw new IOException("delete command fail");
			}
		} catch (IOException e) {
			final StringBuilder errorSB = new StringBuilder();
			errorSB.append("Can not delete file [");
			errorSB.append(filePattern);
			errorSB.append("] : IOException : ");
			errorSB.append(e.getMessage());
			throw new MessagingException(errorSB.toString());
		}
	}

	private boolean del(File readDirectory, String filePattern)
			throws IOException {
		final File[] files = FileTransferUtils.listFiles(readDirectory,
				filePattern);
		boolean isDeleted = false;
		if (files.length > 0) {
			isDeleted = files[0].delete();
		} else {
			throw new IOException("file : '" + filePattern + "' not found");
		}
		return isDeleted;
	}
}
