/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.bc.filetransfer.service.provide;

import java.io.File;
import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.jbi.messaging.MessagingException;
import javax.xml.namespace.QName;

import org.ow2.petals.bc.filetransfer.FileTransferConstants;
import org.ow2.petals.bc.filetransfer.util.FileTransferUtils;
import org.ow2.petals.component.framework.api.Message.MEPConstants;
import org.ow2.petals.component.framework.api.configuration.ConfigurationExtensions;
import org.ow2.petals.component.framework.api.exception.PEtALSCDKException;
import org.ow2.petals.component.framework.api.message.Exchange;
import org.ow2.petals.component.framework.util.SourceUtil;
import org.w3c.dom.Document;
import org.w3c.dom.Node;

import com.ebmwebsourcing.easycommons.xml.XMLHelper;

/***
 * List "folder" contents.
 * @author Mathieu CARROLLE - EBM WebSourcing
 */
public class DirService extends AbstractFileService {

	public DirService(ConfigurationExtensions extensions, Logger logger) {
		super(extensions, logger);
	}

	@Override
	public void process(Exchange exchange, Document inMessageDoc)
			throws MessagingException {
		if (!exchange.isInOutPattern()) {
			throw new MessagingException(
					FileTransferUtils.getValidMepMessageForOperation(
							FileTransferConstants.DIR_OPERATION,
							MEPConstants.IN_OUT_PATTERN));
		}
		String readPath = null;
		try {
			final File readDirectory = FileTransferUtils
					.getFolderPath(extensions);
			readPath = readDirectory.getAbsolutePath();

			final Node filePatternNode = XMLHelper.findChild(
					inMessageDoc.getFirstChild(), null,
					FileTransferConstants.PARAM_FILENAME, false);
			String filePattern = null;
			if (filePatternNode != null) {
				filePattern = filePatternNode.getTextContent();
			}

			this.addMonitBeginStepExtTrace(filePattern, readDirectory.getName());

			final String[] fileNames = this.dir(readDirectory);
			final String outResponse = this.generateFileNameList(fileNames,
					exchange.getOperation());
			exchange.setOutMessageContent(SourceUtil.createSource(outResponse));
			this.addMonitEndStepExtTrace();
		} catch (IOException e) {
			FileTransferUtils.setIOFaultOnExchange(exchange,
					"Can not list files for directory : [" + readPath
							+ "]. Cause : " + e.getMessage());
		} catch (final PEtALSCDKException e) {
			FileTransferUtils.setIOFaultOnExchange(exchange,
					"Can not list files for directory : [" + readPath
							+ "]. Cause : " + e.getMessage());
		}
		if (this.logger.isLoggable(Level.FINEST)) {
			this.logger.finest("DIR operation ended");
		}
	}

	/***
	 * 
	 * @param readDirectory
	 * @return
	 */
	private String[] dir(File readDirectory) {
		return readDirectory.list();
	}

	/**
	 * generates the XML representation of the file name list
	 * 
	 * @param names
	 * @return
	 */
	public String generateFileNameList(String[] names, QName operation) {
		final StringBuilder result = new StringBuilder();
		result.append("<tns:" + operation.getLocalPart()
				+ "Response xmlns:tns='");
		result.append(operation.getNamespaceURI());
		result.append("'>");
		for (String string : names) {
			result.append("<tns:filename>");
			result.append(string);
			result.append("</tns:filename>");
		}
		result.append("</tns:" + operation.getLocalPart() + "Response>");
		return result.toString();
	}

}
